"""Network"""
import urllib.parse
import re


def url_encoding_to_utf_8(url):
	"""url_encoding_to_utf_8(url)"""
	url = urllib.parse.unquote(url)
	return url


def check_valid_url(url):
	regex = re.compile(
	        r'^(?:http|ftp)s?://' # http:// or https://
	        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|' #domain...
	        r'localhost|' #localhost...
	        r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})' # ...or ip
	        r'(?::\d+)?' # optional port
	        r'(?:/?|[/?]\S+)$', re.IGNORECASE)

	return re.match(regex, url) is not None

if __name__ == '__main__':
	pass